@@ -2,7 +2,6 @@ package all_test
 
 import (
 	_ "embed"
-	"fmt"
 	"net"
 	"testing"
 	"time"
@@ -282,8 +281,8 @@ ID    NAME       IP RANGE       SERVERS    AGE
 
 FIREWALLS
 ---
-ID    NAME   RULES COUNT   APPLIED TO COUNT             
-123   test   5 Rules       2 Servers | 0 Label Selectors
+ID    NAME   RULES COUNT   APPLIED TO COUNT                AGE
+123   test   5 Rules       2 Servers | 0 Label Selectors   7m 
 
 CERTIFICATES
 ---
@@ -391,8 +390,6 @@ func TestListAllPaidJSON(t *testing.T) {
 
 	jsonOut, errOut, err := fx.Run(cmd, []string{"--paid", "-o=json"})
 
-	fmt.Println(jsonOut)
-
 	require.NoError(t, err)
 	assert.Empty(t, errOut)
 	assert.JSONEq(t, allListResponseJSON, jsonOut)
