@@ -10,6 +10,7 @@ import (
 func NewCommand(s state.State) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:                   "image",
+		Aliases:               []string{"images"},
 		Short:                 "Manage Images",
 		Args:                  util.Validate,
 		TraverseChildren:      true,
@@ -26,8 +27,8 @@ func NewCommand(s state.State) *cobra.Command {
 	)
 
 	util.AddGroup(cmd, "protection", "Protection",
-		EnableProtectionCmd.CobraCommand(s),
-		DisableProtectionCmd.CobraCommand(s),
+		ChangeProtectionCmds.EnableCobraCommand(s),
+		ChangeProtectionCmds.DisableCobraCommand(s),
 	)
 	return cmd
 }
