@@ -9,16 +9,15 @@ import (
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
-var DeleteCmd = base.DeleteCmd{
+var DeleteCmd = base.DeleteCmd[*hcloud.Network]{
 	ResourceNameSingular: "Network",
 	ResourceNamePlural:   "Networks",
 	ShortDescription:     "Delete a network",
 	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.Network().Names },
-	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (interface{}, *hcloud.Response, error) {
+	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (*hcloud.Network, *hcloud.Response, error) {
 		return s.Client().Network().Get(s, idOrName)
 	},
-	Delete: func(s state.State, _ *cobra.Command, resource interface{}) (*hcloud.Action, error) {
-		network := resource.(*hcloud.Network)
+	Delete: func(s state.State, _ *cobra.Command, network *hcloud.Network) (*hcloud.Action, error) {
 		_, err := s.Client().Network().Delete(s, network)
 		return nil, err
 	},
