@@ -10,6 +10,7 @@ import (
 func NewCommand(s state.State) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:                   "network",
+		Aliases:               []string{"networks"},
 		Short:                 "Manage Networks",
 		Args:                  util.Validate,
 		TraverseChildren:      true,
@@ -28,8 +29,8 @@ func NewCommand(s state.State) *cobra.Command {
 	)
 
 	util.AddGroup(cmd, "protection", "Protection",
-		EnableProtectionCmd.CobraCommand(s),
-		DisableProtectionCmd.CobraCommand(s),
+		ChangeProtectionCmds.EnableCobraCommand(s),
+		ChangeProtectionCmds.DisableCobraCommand(s),
 	)
 
 	util.AddGroup(cmd, "route", "Routes",
