@@ -14,7 +14,7 @@ var LabelCmds = base.LabelCmds[*hcloud.PrimaryIP]{
 	ResourceNameSingular:   "Primary IP",
 	ShortDescriptionAdd:    "Add a label to a Primary IP",
 	ShortDescriptionRemove: "Remove a label from a Primary IP",
-	NameSuggestions:        func(c hcapi2.Client) func() []string { return c.PrimaryIP().Names },
+	NameSuggestions:        func(c hcapi2.Client) func() []string { return c.PrimaryIP().Names(false, false, nil) },
 	LabelKeySuggestions:    func(c hcapi2.Client) func(idOrName string) []string { return c.PrimaryIP().LabelKeys },
 	Fetch: func(s state.State, idOrName string) (*hcloud.PrimaryIP, error) {
 		primaryIP, _, err := s.Client().PrimaryIP().Get(s, idOrName)
