@@ -11,15 +11,14 @@ import (
 	"github.com/hetznercloud/hcloud-go/v2/hcloud"
 )
 
-var SetRDNSCmd = base.SetRdnsCmd{
+var SetRDNSCmd = base.SetRdnsCmd[*hcloud.PrimaryIP]{
 	ResourceNameSingular: "Primary IP",
 	ShortDescription:     "Change reverse DNS of a Primary IP",
-	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.PrimaryIP().Names },
-	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (interface{}, *hcloud.Response, error) {
+	NameSuggestions:      func(c hcapi2.Client) func() []string { return c.PrimaryIP().Names(false, false, nil) },
+	Fetch: func(s state.State, _ *cobra.Command, idOrName string) (*hcloud.PrimaryIP, *hcloud.Response, error) {
 		return s.Client().PrimaryIP().Get(s, idOrName)
 	},
-	GetDefaultIP: func(resource interface{}) net.IP {
-		primaryIP := resource.(*hcloud.PrimaryIP)
+	GetDefaultIP: func(primaryIP *hcloud.PrimaryIP) net.IP {
 		return primaryIP.IP
 	},
 }
